@@ -4,14 +4,21 @@
 """Pragmatic.Pragmatic: provides entry point main()."""
 
 
-__version__ = "0.0.14"
+__version__ = "0.0.19"
 
 from . import Stuff
 from .Registry import Registry
 from .ArgParser import ParseArgs, Test
 from .GetRelease import Get
+import os
+import pathlib
+
+def GetDataDir():
+	dir = os.path.dirname(os.path.realpath(__file__))
+	return os.path.join(dir, 'data')
 
 def Update():
+	os.makedirs(GetDataDir())
 	Get('LLVM', 'llvm-0.1')
 	Get('PragmaticPlugin', '0.1')
 
@@ -19,4 +26,8 @@ def Update():
 def Main():
 	print(f"Running pragmatic version {__version__}.")
 
+
+	if (not pathlib.Path(GetDataDir()).exists()):
+		Update()
+
 	ParseArgs()
\ No newline at end of file
